@@ -1,7 +1,7 @@
 package Complete::Bash;
 
-our $DATE = '2018-10-10'; # DATE
-our $VERSION = '0.320'; # VERSION
+our $DATE = '2019-06-25'; # DATE
+our $VERSION = '0.321'; # VERSION
 
 use 5.010001;
 use strict;
@@ -461,8 +461,45 @@ _
             pos=>0,
         },
         opts => {
+            summary => 'Specify options',
             schema=>'hash*',
             pos=>1,
+            description => <<'_',
+
+Known options:
+
+* word
+
+  A workaround. String. For now, see source code for more details.
+
+* show_summaries
+
+  Whether to show item's summaries. Boolean, default is from
+  COMPLETE_BASH_SHOW_SUMMARIES environment variable or 1.
+
+  An answer item contain summary, which is a short description about the item,
+  e.g.:
+
+      [{word=>"-a"    , summary=>"Show hidden files"},
+       {word=>"-l"    , summary=>"Show details"},
+       {word=>"--sort", summary=>"Specify sort order"}],
+
+  When summaries are not shown, user will just be seeing something like:
+
+      -a
+      -l
+      --sort
+
+  But when summaries are shown, user will see:
+
+      -a         -- Show hidden files
+      -l         -- Show details
+      --sort     -- Specify sort order
+
+  which is quite helpful.
+
+_
+
         },
     },
     result => {
@@ -520,8 +557,11 @@ sub format_completion {
     }
 
     my @res;
+    my @summaries;
+    my $has_summary;
     for my $entry (@$comp) {
-        my $word = ref($entry) eq 'HASH' ? $entry->{word} : $entry;
+        my $word    = ref($entry) eq 'HASH' ? $entry->{word}    : $entry;
+        my $summary = (ref($entry) eq 'HASH' ? $entry->{summary} : undef) // '';
         if ($esc_mode eq 'shellvar') {
             # don't escape $
             $word =~ s!([^A-Za-z0-9,+._/\$~-])!\\$1!g;
@@ -532,8 +572,37 @@ sub format_completion {
             $word =~ s!([^A-Za-z0-9,+._/:~-])!\\$1!g;
         }
         push @res, $word;
+        push @summaries, $summary;
+        $has_summary = 1 if length $summary;
     }
 
+  INSERT_SUMMARIES: {
+        last if @res <= 1;
+        last unless $has_summary;
+        last unless $opts->{show_summaries} //
+            $ENV{COMPLETE_BASH_SHOW_SUMMARIES} // 1;
+        my $columns = do {
+            if (eval { require Term::Size; 1 }) {
+                my ($columns, undef) = Term::Size::chars();
+                $columns;
+            } else {
+                $ENV{COLUMNS} // 80;
+            }
+        };
+        my $width = 8;
+        for (@res) {
+            $width = length if $width < length;
+        }
+        for (0..$#res) {
+            my $summary = $summaries[$_];
+            if (length $summary) {
+                $res[$_] = sprintf("%-${width}s -- %s", $res[$_], $summary);
+            }
+            $res[$_] .= " " x ($columns - length($res[$_]))
+                if length($res[$_]) < $columns;
+        }
+    } # INSERT_SUMMARIES
+
     if ($as eq 'array') {
         return \@res;
     } else {
@@ -556,7 +625,7 @@ Complete::Bash - Completion routines for bash shell
 
 =head1 VERSION
 
-This document describes version 0.320 of Complete::Bash (from Perl distribution Complete-Bash), released on 2018-10-10.
+This document describes version 0.321 of Complete::Bash (from Perl distribution Complete-Bash), released on 2019-06-25.
 
 =head1 DESCRIPTION
 
@@ -689,16 +758,55 @@ Either an array or hash. See function description for more details.
 
 =item * B<$opts> => I<hash>
 
+Specify options.
+
+Known options:
+
+=over
+
+=item * word
+
+A workaround. String. For now, see source code for more details.
+
+=item * show_summaries
+
+Whether to show item's summaries. Boolean, default is from
+COMPLETE_BASH_SHOW_SUMMARIES environment variable or 1.
+
+An answer item contain summary, which is a short description about the item,
+e.g.:
+
+  [{word=>"-a"    , summary=>"Show hidden files"},
+   {word=>"-l"    , summary=>"Show details"},
+   {word=>"--sort", summary=>"Specify sort order"}],
+
+When summaries are not shown, user will just be seeing something like:
+
+  -a
+  -l
+  --sort
+
+But when summaries are shown, user will see:
+
+  -a         -- Show hidden files
+  -l         -- Show details
+  --sort     -- Specify sort order
+
+which is quite helpful.
+
+=back
+
 =back
 
 Return value: Formatted string (or array, if `as` is set to `array`) (str|array)
 
 
+
 =head2 join_wordbreak_words
 
 Usage:
 
- join_wordbreak_words() -> [status, msg, result, meta]
+ join_wordbreak_words() -> [status, msg, payload, meta]
 
 Post-process parse_cmdline() result by joining some words.
 
@@ -729,13 +837,14 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
+
 =head2 parse_cmdline
 
 Usage:
@@ -874,6 +983,7 @@ arguments only (like in C<@ARGV>), you need to strip the first element from
 C<$words> and reduce C<$cword> by 1.
 
 
+
 =head2 point
 
 Usage:
@@ -912,6 +1022,11 @@ Return value:  (any)
 
 =head1 ENVIRONMENT
 
+=head2 COMPLETE_BASH_SHOW_SUMMARIES
+
+Bool. Will set the default for C<show_summaries> option in
+L</format_completion>.
+
 =head2 COMPLETE_BASH_TRACE
 
 Bool. If set to true, will produce more log statements to L<Log::ger>.
@@ -953,7 +1068,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
